#!/bin/sh
#

#
# Include config variables
#
source ./config


#
# Try to find wish 8.3
#
test -x "$WISH" || WISH=$( (type -p wish8.3 || type -p wish) 2>/dev/null)
test -x "$WISH" || {

	echo "No wish8.3 or wish shell found."
	echo "Please install Tcl/Tk or edit the file 'config' by hand."
	exit 1
	}

#
# Try to find tclsh 8.3
#
test -x "$TCLSH" || TCLSH=$( (type -p tclsh8.3 || type -p tclsh) 2>/dev/null)
test -x "$TCLSH" || {

	echo "No tclsh8.3 or tclsh shell found."
        echo "Please install Tcl/Tk or edit the file 'config' by hand."
        exit 1
        }

#
# Build the tkpasman executable
#
{
sed -e "
s,@wish@,${WISH},
s,@tclsh@,${TCLSH},
s,@configfile@,${CONFIGFILE},
s,@pwdfile@,${PWDFILE},
s,@version@,${VERSION},
" tkpasman-hdr.tcl

#
# If requested, find and initialize OpenSSL
#
if test "${USE_OPENSSL}" == "true" ; then

  # find openssl
  found=0
  if test -x "{$OPENSSL}" ; then
    found=1
  else
    IFS=':'
    for prog in openssl ssl
    do
      for path in $PATH    \
        /usr/ssl/bin       \
        /usr/openssl/bin   \
        /usr/local/ssl/bin \
        /usr/local/openssl/bin
      do
        if test -x $path/$prog ; then
          found=1
          OPENSSL=$path/$prog
          break 2
        fi
      done
    done
  fi
  if test $found -gt 0 ; then
    #OpenSSL was found.
    if ENC=`$OPENSSL list-cipher-commands|sort|grep -E "^($ENC)\$"|head -1` ; then
      if echo bla|$OPENSSL $ENC -pass stdin|
          $OPENSSL $ENC -d -k bla >/dev/null; then
        # It Works!
        echo "set ssl(cmd) {$OPENSSL}"
        echo "set ssl(enc) {$ENC}"
        echo "set ssl(passwd) {}"
        echo "Enabling OpenSSL support:" >&2
        echo "  openssl: $OPENSSL" >&2
        echo "  enc:     $ENC" >&2
        if echo bla|$OPENSSL $ENC -salt -pass stdin|
            $OPENSSL $ENC -d -k bla >/dev/null; then
          # Salt option works!
          echo "set ssl(salt) -salt"
          echo "  salt:    yes" >&2
        else
          echo "set ssl(salt) {}"
          echo "  salt:    no" >&2
        fi
        cat WARNING >&2
      fi
    fi
  fi
fi

#
# Build in Help file
#
echo -n "set Help {"
cat README
echo "}"

#
# Assemble the rest of the program
#
cat cooltk.tcl tkpasman.tcl
} > tkpasman
chmod 0755 tkpasman
